@@ -204,9 +204,7 @@ def _data_to_list(data: Union[list, tuple, dict],
         else:
             return_list.extend([str(i)])
 
-    if process_content:
-        return_list = [i.value if isinstance(i, Cell) else i for i in return_list]
-    return return_list
+    return [_process_content(i) for i in return_list] if process_content else return_list
 
 
 def _data_to_list_or_dict(data: Union[list, tuple, dict],
@@ -299,9 +297,9 @@ def _parse_coord(coord: Union[int, str, list, tuple],
             raise ValueError('只输入行号时必须同时输入列号')
 
     if isinstance(coord, str):
-        if ',' in coord:  # 'A3'形式
+        if ',' in coord:  # '3,1'形式
             coord = coord.replace(' ', '').split(',')
-        else:  # '3,1'形式
+        else:  # 'A3'形式
             xy = coordinate_from_string(coord)
             return xy[1], column_index_from_string(xy[0])
 
@@ -312,6 +310,10 @@ def _parse_coord(coord: Union[int, str, list, tuple],
 
 
 def _process_content(content: Any) -> Union[int, str, float, None]:
+    """处理要写入的数据                  \n
+    :param content: 未处理的数据内容
+    :return: 处理后的数据
+    """
     if isinstance(content, (int, str, float, type(None))):
         return content
     elif isinstance(content, Cell):
